@@ -104,7 +104,7 @@ def str_to_bool(s):
 
 
 def bool_to_jsBool(value):
-    if value == True:
+    if value is True:
         return "true"
     return "false"
 
@@ -209,6 +209,7 @@ class NotImplement(Exception):
 
 
 class Stack:
+    stack = []
 
     def __iter__(self):
         return self.stack.__iter__()
@@ -229,9 +230,14 @@ class Stack:
             return None
         return self.stack.pop()
 
+    def extend(self, lst):
+        if isinstance(lst, list):
+            for itm in lst:
+                self.push(itm)
+
     def push(self, item, exists_function=None, logger=None):
         if callable(exists_function):
-            if exists_function(item) == False:
+            if exists_function(item) is False:
                 self.stack.append(item)
                 if isinstance(logger, Logger):
                     logger.debug(f'self.stack.append: {item}')
@@ -278,7 +284,7 @@ class Stack:
         return res[0]
 
     def __str__(self):
-        return "\n" + ', '.join([str(item.id) for item in self.stack])
+        return "\n" .join([str(item) for item in self.stack])
 
 
 class StackLocs(Stack):
@@ -333,3 +339,6 @@ class Wrapper:
     @property
     def dict(self):
         return self.__dict__
+
+    def __str__(self):
+        return str(self.dict)
