@@ -59,17 +59,17 @@ class DSRequest(RPCRequest):
     @property
     def user(self):
         from isc_common.auth.models.user import User
-        if self._user == None:
-            if self.httpHeaders != None and self.httpHeaders.USER_ID:
+        if self._user is None:
+            if self.httpHeaders is not None and self.httpHeaders.USER_ID:
                 self._user = User.objects.get(id=self.httpHeaders.USER_ID)
                 return self._user
             else:
-                if self.transaction != None:
+                if self.transaction is not None:
                     operations = self.transaction.operations
                     if isinstance(operations, list):
                         for operation in operations:
                             data = operation.data
-                            if data.httpHeaders != None and data.httpHeaders.USER_ID != None:
+                            if data.httpHeaders is not None and data.httpHeaders.USER_ID is not None:
                                 self._user = User.objects.get(id=data.httpHeaders.USER_ID)
                                 return self._user
 
@@ -107,7 +107,7 @@ class DSRequest(RPCRequest):
 
     def __init__(self, request):
 
-        if request != None and request.body != b'':
+        if request is not None and request.body != b'':
             self.json = BytesToJson(request.body)
             if isinstance(self.json, dict) and len(self.json) > 0:
                 data = self.json.get('data')
@@ -115,32 +115,32 @@ class DSRequest(RPCRequest):
                     httpHeaders = data.get('httpHeaders')
                     if isinstance(httpHeaders, dict):
 
-                        if httpHeaders.get('WS_CHANNEL') != None:
+                        if httpHeaders.get('WS_CHANNEL') is not None:
                             self.ws_channel = httpHeaders.get('WS_CHANNEL')
 
-                        if httpHeaders.get('WS_PORT') != None:
+                        if httpHeaders.get('WS_PORT') is not None:
                             self.ws_port = httpHeaders.get('WS_PORT')
 
-                        if httpHeaders.get('HOST') != None:
+                        if httpHeaders.get('HOST') is not None:
                             self.host = httpHeaders.get('HOST')
 
-                        if httpHeaders.get('USERNAME') != None:
+                        if httpHeaders.get('USERNAME') is not None:
                             self.set_user_data(user=httpHeaders.get('USERNAME'))
 
-                        if httpHeaders.get('USER_ID') != None:
+                        if httpHeaders.get('USER_ID') is not None:
                             self.set_user_data(user=httpHeaders.get('USER_ID'))
 
                         delAttr(self.json.get('data'), 'httpHeaders')
                     else:
-                        if data.get('user_id') != None:
+                        if data.get('user_id') is not None:
                             self.set_user_data(user=data.get('user_id'))
                 else:
                     login = self.json.get('login')
-                    if login != None:
+                    if login is not None:
                         self.set_user_data(user=login)
                     else:
                         httpHeaders = self.json.get('httpHeaders')
-                        if httpHeaders != None:
+                        if httpHeaders is not None:
                             self.set_user_data(user=httpHeaders.get('USER_ID'))
 
         RPCRequest.__init__(self, self.json)
@@ -183,7 +183,11 @@ class DSRequest(RPCRequest):
 
     def get_criteria(self, excluded_keys=['grid']):
         data = self.get_data(excluded_keys=excluded_keys)
-        criteria = data.get('criteria')
+        if isinstance(data, dict):
+            criteria = data.get('criteria')
+        else:
+            return dict()
+
         if isinstance(criteria, list):
             return criteria
         else:
