@@ -79,6 +79,8 @@ def ToDecimal(s):
     if isinstance(s, int):
         return Decimal(s)
     elif isinstance(s, str):
+        if len(s) == 0:
+            return 0
         return Decimal(s)
     elif isinstance(s, float):
         return Decimal(s)
