@@ -61,7 +61,7 @@ class Progress:
         self.id = id
         self.enable_ws_progress = IsBitOff(self.props, 1)
 
-        if self.enable_ws_progress == True:
+        if self.enable_ws_progress is True:
             if isinstance(user, int):
                 self.user = User.objects.get(id=user)
             elif isinstance(user, User):
@@ -71,7 +71,7 @@ class Progress:
 
         self.qty = qty
 
-        if self.enable_ws_progress == False:
+        if self.enable_ws_progress is False:
             self.pbar = tqdm(total=qty)
         else:
             # if self.qty > 0:
@@ -122,8 +122,8 @@ class Progress:
         from isc_common.models.deleted_progresses import Deleted_progresses
 
         res = 0
-        if self.enable_ws_progress == True:
-            if self.progress != None:
+        if self.enable_ws_progress is True:
+            if self.progress is not None:
                 self.progress.setCntDone(self.cnt, self.id)
                 self.cnt += 1
                 if self.qty == self.cnt:
@@ -139,35 +139,35 @@ class Progress:
         return res
 
     def setContentsLabel(self, content):
-        if self.progress != None:
+        if self.progress is not None:
             self.progress.setContentsLabel(labelContents=content, id=self.id)
             self.progresses.label_contents = content
             self.progresses.save()
 
     def setQty(self, qty):
-        if self.progress != None:
+        if self.progress is not None:
             self.progress.setCntAll(cntAll=qty, id=self.id)
             self.progresses.qty = qty
             self.progresses.save()
 
     def sendInfo(self, message):
-        if self.progress != None:
+        if self.progress is not None:
             self.progress.sendInfo(message=message)
 
     def sendWarn(self, message):
-        if self.progress != None:
+        if self.progress is not None:
             self.progress.sendWarn(message=message)
 
     def sendError(self, message, stackTrace=None):
-        if self.progress != None:
+        if self.progress is not None:
             self.progress.sendError(message=message, stackTrace=stackTrace)
 
     def sendMessage(self, type, message=None):
-        if self.progress != None:
+        if self.progress is not None:
             self.progress.sendMessage(type=type, message=message)
 
     def close(self):
-        if self.progress != None:
+        if self.progress is not None:
             self.progress.close(self.id)
             try:
                 self.progresses.delete()
